summaryrefslogtreecommitdiff
path: root/cvscompile.sh
diff options
context:
space:
mode:
Diffstat (limited to 'cvscompile.sh')
-rwxr-xr-xcvscompile.sh17
1 files changed, 10 insertions, 7 deletions
diff --git a/cvscompile.sh b/cvscompile.sh
index e4159a9d3..ae6df4f4c 100755
--- a/cvscompile.sh
+++ b/cvscompile.sh
@@ -1,11 +1,14 @@
#!/bin/sh
# Run this to generate all the initial Makefiles, etc.
-## extract autoconf version
-autoconf_2_5x=no
-AC="`autoconf --version | sed -n 1p | sed -e 's/[a-zA-Z\ \.\(\)]//g'`"
-if [ `expr $AC` -ge 250 ]; then
- autoconf_2_5x=yes
+## extract automake version
+automake_1_5x=no
+AM="`automake --version | sed -n 1p | sed -e 's/[a-zA-Z\ \.\(\)]//g'`"
+if test $AM -lt 100 ; then
+ AM=`expr $AM \* 10`
+fi
+if [ `expr $AM` -ge 150 ]; then
+ automake_1_5x=yes
fi
rm -f config.cache
@@ -19,8 +22,8 @@ if test -d $srcdir/m4; then
for m4f in $m4_files; do
cat $srcdir/m4/$m4f >> acinclude.m4
done
- ## autoconf 2.5x implement AM_PROG_AS, not older ones, so add it.
- if test x"$autoconf_2_5x" = x"no"; then
+ ## automake 1.5x implement AM_PROG_AS, not older ones, so add it.
+ if test x"$automake_1_5x" = x"no"; then
cat $srcdir/m4/as.m4 >> acinclude.m4
fi
else